========================
Help pages for Telemeta
========================

In order to get access to some resticted items on this site, please contact:

    Aude Julien <aude.da-cruz-lima (at) mae.u-paris10.fr>

For technical assistance, please join our mailing list:

    `http://lists.parisson.com/cgi-bin/mailman/listinfo/telemeta <http://lists.parisson.com/cgi-bin/mailman/listinfo/telemeta>`_

or contact the hotline by email:

     support@parisson.com

or twitter :

    `http://twitter.com/telemeta <http://twitter.com/telemeta>`_

For more informations about the Telemeta system, see `telemeta.org <http://telemeta.org>`_

Telemeta uses the audio librairy TimeSide : `code.google.com/p/timeside/ <http://code.google.com/p/timeside/>`_